@@ -156,10 +156,10 @@ MyMoneyMoney::MyMoneyMoney(const TQString& pszAmount)
     negChars += "()";
   }
   validChars += negChars;
-  // qDebug("0: '%s'", validChars.data());
+  // tqDebug("0: '%s'", validChars.data());
 
   TQRegExp invChars(TQString("[^%1]").arg(validChars));
-  // qDebug("1: '%s'", res.data());
+  // tqDebug("1: '%s'", res.data());
   res.remove(invChars);
 
   TQRegExp negCharSet(TQString("[%1]").arg(negChars));
@@ -168,10 +168,10 @@ MyMoneyMoney::MyMoneyMoney(const TQString& pszAmount)
     isNegative = true;
     res.remove(negCharSet);
   }
-  // qDebug("2: '%s' %s", res.data(), isNegative ? "(-)" : "");
+  // tqDebug("2: '%s' %s", res.data(), isNegative ? "(-)" : "");
   int pos;
 
-  // qDebug("3: '%s'", res.data());
+  // tqDebug("3: '%s'", res.data());
   if((pos = res.find(_decimalSeparator)) != -1) {
     // make sure, we get the denominator right
     m_denom = precToDenom(res.length() - pos - 1);
@@ -179,7 +179,7 @@ MyMoneyMoney::MyMoneyMoney(const TQString& pszAmount)
     // now remove the decimal symbol
     res.remove(pos, 1);
   }
-  // qDebug("4: '%s'", res.data());
+  // tqDebug("4: '%s'", res.data());
   if(res.length() > 0)
     m_num = atoll( res );
 
@@ -223,7 +223,7 @@ TQString MyMoneyMoney::formatMoney(const TQString& currency, const int prec, boo
   m_64Value = convert(denom).m_num;
 
   // Once we really support multiple currencies then this method will
-  // be much better than using KGlobal::locale()->formatMoney.
+  // be much better than using TDEGlobal::locale()->formatMoney.
   bool bNegative = false;
   signed64 left = m_64Value / denom;
   signed64 right = m_64Value % denom;
@@ -353,13 +353,13 @@ TQDataStream &operator<<(TQDataStream &s, const MyMoneyMoney &_money)
   switch(MyMoneyMoney::_fileVersion) {
     case MyMoneyMoney::FILE_4_BYTE_VALUE:
       if(money.m_num & 0xffffffff00000000LL)
-        qWarning("Lost data while writing out MyMoneyMoney object using deprecated 4 byte writer");
+        tqWarning("Lost data while writing out MyMoneyMoney object using deprecated 4 byte writer");
 
       s << static_cast<TQ_INT32> (money.m_num & 0xffffffff);
       break;
 
     default:
-      qDebug("Unknown file version while writing MyMoneyMoney object! Use FILE_8_BYTE_VALUE");
+      tqDebug("Unknown file version while writing MyMoneyMoney object! Use FILE_8_BYTE_VALUE");
       // tricky fall through here
 
     case MyMoneyMoney::FILE_8_BYTE_VALUE:
@@ -381,7 +381,7 @@ TQDataStream &operator>>(TQDataStream &s, MyMoneyMoney &money)
       break;
 
     default:
-      qDebug("Unknown file version while writing MyMoneyMoney object! FILE_8_BYTE_VALUE assumed");
+      tqDebug("Unknown file version while writing MyMoneyMoney object! FILE_8_BYTE_VALUE assumed");
       // tricky fall through here
 
     case MyMoneyMoney::FILE_8_BYTE_VALUE:
@@ -724,7 +724,7 @@ const MyMoneyMoney MyMoneyMoney::convert(const signed64 _denom, const roundingMe
           break;
 
         case RndNever:
-          qWarning("MyMoneyMoney: have remainder \"%Ld/%Ld\"->convert(%Ld, %d)",
+          tqWarning("MyMoneyMoney: have remainder \"%Ld/%Ld\"->convert(%Ld, %d)",
                     m_num, m_denom, _denom, how);
           break;
       }
