@@ -21,10 +21,10 @@
 #include <tqfile.h>
 
 #include <kdebug.h>
-#include <kdeversion.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <klocale.h>
+#include <tdeversion.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 
 // DOH, mmreport.h uses this without including it!!
@@ -834,8 +834,8 @@ void PivotTableTest::testColumnType()
   CPPUNIT_ASSERT(spending_days.m_grid.m_total[eActual][13] == -moSolo);
   CPPUNIT_ASSERT(spending_days.m_grid.m_total[eActual].m_total == -moSolo-moParent2);
 
-  unsigned save_dayweekstart = KGlobal::locale()->weekStartDay();
-  KGlobal::locale()->setWeekStartDay(2);
+  unsigned save_dayweekstart = TDEGlobal::locale()->weekStartDay();
+  TDEGlobal::locale()->setWeekStartDay(2);
 
   filter.setDateFilter(TQDate(2004,7,2),TQDate(2004,8,1));
   filter.setRowType( MyMoneyReport::eExpenseIncome );
@@ -846,7 +846,7 @@ void PivotTableTest::testColumnType()
   PivotTable spending_weeks( filter );
   writeTabletoHTML(spending_weeks,"Spending by Weeks.html");
 
-  KGlobal::locale()->setWeekStartDay(save_dayweekstart);
+  TDEGlobal::locale()->setWeekStartDay(save_dayweekstart);
 
   CPPUNIT_ASSERT(spending_weeks.m_grid.m_total[eActual][0] == moZero);
   CPPUNIT_ASSERT(spending_weeks.m_grid.m_total[eActual][1] == -moParent2);
